@@ -14,12 +14,14 @@ DCORE_BEGIN_NAMESPACE
 
 class ConsoleAppender;
 class RollingFileAppender;
+class JournalAppender;
 
 class LIBDTKCORESHARED_EXPORT DLogManager
 {
 public:
     static void registerConsoleAppender();
     static void registerFileAppender();
+    static void registerJournalAppender();
 
     static QString getlogFilePath();
 
@@ -32,13 +34,16 @@ public:
     static void setLogFormat(const QString &format);
 
 private:
+//TODO: move it to private class (DTK6)
     QString m_format;
     QString m_logPath;
     ConsoleAppender* m_consoleAppender;
     RollingFileAppender* m_rollingFileAppender;
+    JournalAppender* m_journalAppender;
 
     void initConsoleAppender();
     void initRollingFileAppender();
+    void initJournalAppender();
     QString joinPath(const QString &path, const QString &fileName);
 
     inline static DLogManager* instance(){
