@@ -7,6 +7,7 @@
 #include <QString>
 #include <QDebug>
 #include <QDateTime>
+#include <QElapsedTimer>
 
 #include "dloggerdefs.h"
 
@@ -40,7 +41,7 @@ public:
     void registerAppender(AbstractAppender *appender);
     void registerCategoryAppender(const QString &category, AbstractAppender *appender);
 
-    void logToGlobalInstance(const QString &category, bool logToGlobal = false);
+    QT_DEPRECATED_X("no longer take effect") void logToGlobalInstance(const QString &category, bool logToGlobal = false);
 
     void setDefaultCategory(const QString &category);
     QString defaultCategory() const;
@@ -137,7 +138,7 @@ public:
 
 private:
     Logger *m_logger;
-    QTime m_time;
+    QElapsedTimer m_time;
     Logger::LogLevel m_logLevel;
     const char *m_file;
     int m_line;
