@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2021 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
@@ -619,7 +619,7 @@ public:
         const auto &dataPaths = DStandardPaths::paths(DStandardPaths::DSG::DataDir);
         paths.reserve(dataPaths.size());
         for (auto item : dataPaths) {
-            paths.prepend(QString("%1/%2/configs/%3").arg(prefix, item, configKey.appId));
+            paths.prepend(QDir::cleanPath(QString("%1/%2/configs/%3").arg(prefix, item, configKey.appId)));
         }
         return paths;
     }
@@ -627,7 +627,7 @@ public:
     inline static QStringList genericMetaDirs(const QString &prefix) {
         QStringList paths;
         for (auto item: DStandardPaths::paths(DStandardPaths::DSG::DataDir)) {
-            paths.prepend(QString("%1/%2/configs").arg(prefix, item));
+            paths.prepend(QDir::cleanPath(QString("%1/%2/configs").arg(prefix, item)));
         }
         return paths;
     }
@@ -957,6 +957,14 @@ DConfigMetaImpl::~DConfigMetaImpl()
     @return
 */
 
+/*!
+@~english
+    @fn void setCachePathPrefix(const QString &prefix) = 0;
+    @brief Set cache's prefix path, it's access permissions is considered by caller,
+and it needs to distinguish the paths of different caches by caller.
+    @param prefix cache's prefix path.
+*/
+
 class Q_DECL_HIDDEN DConfigCacheImpl : public DConfigCache {
 public:
     DConfigCacheImpl(const DConfigKey &configKey, const uint uid, bool global);
@@ -979,20 +987,30 @@ public:
         return values.keyList();
     }
 
-    inline static QString applicationCacheDir(const QString &prefix, const QString &suffix,
-                                              uint userid, const QString &appId) {
-        // If target user is current user, then get the home path by environment variable first.
-        const QString &homePath = (getuid() == userid) ? DStandardPaths::homePath()
-                                                       : DStandardPaths::homePath(userid);
-        if (homePath.isEmpty()) {
-            return QString();
+    inline QString applicationCacheDir(const QString &localPrefix, const QString &suffix) const
+    {
+        QString prefix(cachePrefix);
+        if (prefix.isEmpty()) {
+            // If target user is current user or system user, then get the home path by environment variable first.
+            QString homePath;
+            if (userid == InvalidUID || (getuid() == userid)) {
+                homePath = DStandardPaths::homePath();
+            } else {
+                homePath = DStandardPaths::homePath(getuid());
+            }
+
+            if (homePath.isEmpty())
+                return QString();
+
+            // fallback to default application cache directory.
+            prefix = homePath + QStringLiteral("/.config/dsg/configs");
         }
-        const QString userHomeConfigDir = homePath + QStringLiteral("/.config/dsg/configs") + suffix;
-        return prefix + userHomeConfigDir + QDir::separator() + appId;
+        return QDir::cleanPath(QString("%1/%2/%3").arg(localPrefix, prefix + suffix, configKey.appId));
     }
 
-    inline QString applicationCacheDir(const QString &prefix) const {
-        return applicationCacheDir(prefix, QString(), userid, configKey.appId);
+    inline QString applicationCacheDir(const QString &localPrefix) const
+    {
+        return applicationCacheDir(localPrefix, QString());
     }
 
     inline QString cacheDir(const QString &basePath) {
@@ -1000,23 +1018,28 @@ public:
         return dir.filePath(configKey.fileName + FILE_SUFFIX);
     }
 
-    inline QString globalCacheDir(const QString &prefix) const {
-        // TODO `DSG_APP_DATA` is not set and `appid` is not captured in `DStandardPaths::path`.
-        QString appDataDir = DStandardPaths::path(DStandardPaths::DSG::AppData);
-        if (appDataDir.isEmpty()) {
+    inline QString globalCacheDir(const QString &localPrefix) const {
+        QString prefix(cachePrefix);
+        if (prefix.isEmpty()) {
+            // TODO `DSG_APP_DATA` is not set and `appid` is not captured in `DStandardPaths::path`.
+            QString appDataDir = DStandardPaths::path(DStandardPaths::DSG::AppData);
+            if (appDataDir.isEmpty()) {
 #ifdef D_DSG_APP_DATA_FALLBACK
-            appDataDir = QStringLiteral(D_DSG_APP_DATA_FALLBACK);
-            QFileInfo tmp(appDataDir);
-            if (!tmp.exists() && !tmp.isSymLink() && !QDir::current().mkpath(appDataDir)) {
-                qCDebug(cfLog, "Not found a valid DSG_APP_DATA directory");
-                return QString();
-            }
+                appDataDir = QStringLiteral(D_DSG_APP_DATA_FALLBACK);
+                QFileInfo tmp(appDataDir);
+                if (!tmp.exists() && !tmp.isSymLink() && !QDir::current().mkpath(appDataDir)) {
+                    qCDebug(cfLog, "Not found a valid DSG_APP_DATA directory");
+                    return QString();
+                }
 #else
-            return QString();
+                return QString();
 #endif
+            }
+            // fallback to default global cache directory.
+            prefix = QString("%1/configs").arg(appDataDir);
         }
 
-        return QString("%1/%2/configs/%3").arg(prefix, appDataDir, configKey.appId);
+        return QDir::cleanPath(QString("%1/%2/%3").arg(localPrefix, prefix, configKey.appId));
     }
 
     QString getCacheDir(const QString &localPrefix = QString())
@@ -1027,7 +1050,7 @@ public:
                 return dir;
 
             // Not supported the global config, fallback the config cache data to user directory.
-            return applicationCacheDir(localPrefix, "-fake-global", getuid(), configKey.appId);
+            return applicationCacheDir(localPrefix, "-fake-global");
         } else {
             return applicationCacheDir(localPrefix);
         }
@@ -1065,8 +1088,14 @@ public:
 
     bool save(const QString &localPrefix, QJsonDocument::JsonFormat format, bool sync) override;
 
+    virtual void setCachePathPrefix(const QString &prefix) override
+    {
+        cachePrefix = prefix;
+    }
+
     DConfigKey configKey;
     DConfigInfo values;
+    QString cachePrefix;
     uint userid;
     bool global;
     bool cacheChanged = false;
@@ -1124,6 +1153,7 @@ bool DConfigCacheImpl::save(const QString &localPrefix, QJsonDocument::JsonForma
     if (!cacheChanged)
         return true;
 
+    cacheChanged = false;
     const QString &dir = getCacheDir(localPrefix);
     if (dir.isEmpty()) {
         qCWarning(cfLog, "Falied on saveing, the config cache directory is empty for the user[%d], "
@@ -1202,16 +1232,28 @@ public:
             } else {
                 const auto &metaValue = configMeta->value(key);
                 // sample judgement to reduce a copy of convert.
-                if (metaValue.type() == value.type())
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                if (metaValue.typeId() == value.typeId())
                     return cache->setValue(key, value, configMeta->serial(key), cache->uid(), appid);
 
                 // convert copy to meta's type, it promises `setValue` don't change meta's type.
+                auto copy = value;
+                if (!copy.convert(metaValue.metaType())) {
+                    qCWarning(cfLog) << "check type error, meta type is " << metaValue.metaType().name()
+                                     << ", and now type is " << value.metaType().name();
+                    return false;
+                }
+#else
+                if (metaValue.type() == value.type())
+                    return cache->setValue(key, value, configMeta->serial(key), cache->uid(), appid);
+
                 auto copy = value;
                 if (!copy.convert(metaValue.userType())) {
                     qCWarning(cfLog) << "check type error, meta type is " << metaValue.type()
                                      << ", and now type is " << value.type();
                     return false;
                 }
+#endif
 
                 return cache->setValue(key, copy, configMeta->serial(key), cache->uid(), appid);
             }
@@ -1225,7 +1267,7 @@ public:
         }
         return userCache;
     }
-    QVariant value(const QString &key, DConfigCache *userCache) const
+    QVariant cacheValue(DConfigCache *userCache, const QString &key) const
     {
         // 检查权限
         if (configMeta->permissions(key) != DConfigFile::ReadOnly) {
@@ -1237,7 +1279,13 @@ public:
                 }
             }
         }
-
+        return QVariant();
+    }
+    QVariant value(const QString &key, DConfigCache *userCache) const
+    {
+        const QVariant &v = cacheValue(userCache, key);
+        if (v.isValid())
+            return v;
         return configMeta->value(key);
     }
 
@@ -1281,8 +1329,6 @@ constexpr DConfigFile::Version DConfigFile::supportedVersion()
 DConfigFile::DConfigFile(const QString &appId, const QString &name, const QString &subpath)
     : DObject(*new DConfigFilePrivate(this, appId, name, subpath))
 {
-    Q_ASSERT(!name.isEmpty());
-
     D_D(DConfigFile);
     d->globalCache = new DConfigCacheImpl(d->configKey, InvalidUID, true);
 }
@@ -1340,7 +1386,7 @@ bool DConfigFile::save(const QString &localPrefix, QJsonDocument::JsonFormat for
 @~english
  * @brief DConfigFile::value
  * @param key Configuration name
- * @param uid User id, uid is invalid when the key is global
+ * @param userCache Specific user cache, \a userCache is unused when the key is global
  * @return
  */
 QVariant DConfigFile::value(const QString &key, DConfigCache *userCache) const
@@ -1349,12 +1395,24 @@ QVariant DConfigFile::value(const QString &key, DConfigCache *userCache) const
     return d->value(key, userCache);
 }
 
+/*!
+ * \brief DConfigFile::cacheValue Get a specific user cache's value
+ * \param userCache Specific user cache, it is unused if the \a key is global configuration item
+ * \param key Configuration name
+ * \return
+ */
+QVariant DConfigFile::cacheValue(DConfigCache *userCache, const QString &key) const
+{
+    D_DC(DConfigFile);
+    return d->cacheValue(userCache, key);
+}
+
 /*!
 @~english
     @brief Sets the value in the cache
     \a key Configuration name
     \a value The value to set
-    \a uid User id at setup time
+    \a userCache Specific user cache at setup time
     \a appid Application id at setup time
     @return A value of true indicates that the new value has been reset, and false indicates that it has not been set
  */
