@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
@@ -16,6 +16,7 @@
 #include <QSettings>
 #include <QStandardPaths>
 #include <QDateTime>
+#include <QRegularExpression>
 #include <qmath.h>
 
 #ifdef Q_OS_LINUX
@@ -127,7 +128,7 @@ bool DSysInfoPrivate::splitA_BC_DMode()
         minVersion.D = minv % 10;
     } else if (minorVersion.length() > 0) {
         const QString D = minorVersion.right(1);
-        if (D.contains(QRegExp("[0-9A-Z]"))) {
+        if (D.contains(QRegularExpression("[0-9A-Z]"))) {
             // 0-9...A-Z
             minVersion.D = 10 + static_cast<uint>(D.data()->toLatin1() - 'A');
         } else {
@@ -242,7 +243,11 @@ bool DSysInfoPrivate::ensureOsVersion()
     ok = (osbs.size() >= 2 && osbs.value(0).size() == 5);
     D_ASSET_EXIT(ok, "OsBuild version invalid!");
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    const QStringList &left = osbs.value(0).split(QString(), Qt::SkipEmptyParts);
+#else
     const QStringList &left = osbs.value(0).split(QString(), QString::SkipEmptyParts);
+#endif
     D_ASSET_EXIT(left.size() == 5, "OsBuild version(ls) invalid!");
 
     int idx = 0;
@@ -550,7 +555,9 @@ bool DSysInfo::isDeepin()
 bool DSysInfo::isDDE()
 {
     if (!DSysInfo::isDeepin()) {
-        return qgetenv("XDG_SESSION_DESKTOP") == "deepin";
+        const QByteArray &xsd = qgetenv("XDG_SESSION_DESKTOP");
+        return !xsd.compare("deepin", Qt::CaseInsensitive) ||
+                !xsd.compare("DDE", Qt::CaseInsensitive);
     }
 
     siGlobal->ensureDeepinInfo();
@@ -1043,11 +1050,17 @@ QString DSysInfo::cpuModelName()
 
     // Get the cpu info by executing lscpu command
     if (siGlobal->cpuModelName.isEmpty()) {
+        const auto &lscpu_command = QStandardPaths::findExecutable("lscpu");
+        if (lscpu_command.isEmpty()) {
+            qWarning() << "lscpu not found";
+            return QString();
+        }
         QProcess lscpu;
         QStringList env = QProcess::systemEnvironment();
         env << "LC_ALL=C"; // Add an environment variable
         lscpu.setEnvironment(env);
-        lscpu.start("/usr/bin/lscpu");
+        lscpu.setProgram(lscpu_command);
+        lscpu.start();
         if (lscpu.waitForFinished(3000)) {
             const QMap<QString, QString> map = siGlobal->parseInfoContent(lscpu.readAll());
             if (map.contains("Model name")) {
@@ -1072,6 +1085,9 @@ qint64 DSysInfo::memoryInstalledSize()
 #ifdef Q_OS_LINUX
     // Getting Memory Installed Size
     // TODO: way to not dept on lshw?
+    if (siGlobal->memoryInstalledSize >= 0) {
+        return siGlobal->memoryInstalledSize;
+    }
     if (!QStandardPaths::findExecutable("lshw").isEmpty()) {
         QProcess lshw;
 
@@ -1191,7 +1207,11 @@ QDateTime DSysInfo::shutdownTime()
         const QByteArray data = lastx.readLine(1024);
         //shutdown system down  4.19.0-amd64-des Fri Sep 30 17:53:17 2022 - Sat Oct  8 08:32:47 2022 (7+14:39)
         if (data.startsWith("shutdown")) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            QString timeFmt = QString(data).split(' ', Qt::SkipEmptyParts).mid(4, 5).join(' ');
+#else
             QString timeFmt = QString(data).split(' ', QString::SkipEmptyParts).mid(4, 5).join(' ');
+#endif
             dt = QDateTime::fromString(timeFmt);
             break;
         }
