@@ -6,9 +6,26 @@
 #include <Logger.h>
 #include <ConsoleAppender.h>
 #include <RollingFileAppender.h>
+#include <JournalAppender.h>
+#include "dstandardpaths.h"
 
 DCORE_BEGIN_NAMESPACE
 
+// Courtesy qstandardpaths_unix.cpp
+static void appendOrganizationAndApp(QString &path)
+{
+#ifndef QT_BOOTSTRAPPED
+    const QString org = QCoreApplication::organizationName();
+    if (!org.isEmpty())
+        path += QLatin1Char('/') + org;
+    const QString appName = QCoreApplication::applicationName();
+    if (!appName.isEmpty())
+        path += QLatin1Char('/') + appName;
+#else
+    Q_UNUSED(path);
+#endif
+}
+
 /*!
 @~english
   \class Dtk::Core::DLogManager
@@ -19,11 +36,7 @@ DCORE_BEGIN_NAMESPACE
 
 DLogManager::DLogManager()
 {
-#if !defined(QT_DEBUG) && !defined(QT_MESSAGELOGCONTEXT)
-    m_format = "%{time}{yyyy-MM-dd, HH:mm:ss.zzz} [%{type:-7}] %{message}\n";
-#else
     m_format = "%{time}{yyyy-MM-dd, HH:mm:ss.zzz} [%{type:-7}] [%{file:-20} %{function:-35} %{line}] %{message}\n";
-#endif
 }
 
 void DLogManager::initConsoleAppender(){
@@ -40,6 +53,15 @@ void DLogManager::initRollingFileAppender(){
     logger->registerAppender(m_rollingFileAppender);
 }
 
+
+void DLogManager::initJournalAppender()
+{
+#if (defined BUILD_WITH_SYSTEMD && defined Q_OS_LINUX)
+    m_journalAppender = new JournalAppender();
+    logger->registerAppender(m_journalAppender);
+#endif
+}
+
 /*!
 @~english
   \brief Registers the appender to write the log records to the Console.
@@ -61,6 +83,11 @@ void DLogManager::registerFileAppender() {
     DLogManager::instance()->initRollingFileAppender();
 }
 
+void DLogManager::registerJournalAppender()
+{
+    DLogManager::instance()->initJournalAppender();
+}
+
 /*!
 @~english
   \brief Return the path file log storage.
@@ -75,14 +102,14 @@ QString DLogManager::getlogFilePath()
     //No longer set the default log path (and mkdir) when constructing now, instead set the default value if it's empty when getlogFilePath is called.
     //Fix the problem that the log file is still created in the default path when the log path is set manually.
     if (DLogManager::instance()->m_logPath.isEmpty()) {
-        if (QDir::homePath() == QDir::rootPath()) {
-            qWarning() << "unable to locate the cache directory."
-                       << "logfile path is empty, the log will not be written.\r\n"
-                       << (qgetenv("HOME").isEmpty() ? "the HOME environment variable not set" : "");
+        if (DStandardPaths::homePath().isEmpty()) {
+            qWarning() << "Unable to locate the cache directory, cannot acquire home directory, and the log will not be written to file..";
             return QString();
         }
 
-        QString cachePath = QStandardPaths::standardLocations(QStandardPaths::CacheLocation).at(0);
+        QString cachePath(DStandardPaths::path(DStandardPaths::XDG::CacheHome));
+        appendOrganizationAndApp(cachePath);
+
         if (!QDir(cachePath).exists()) {
             QDir(cachePath).mkpath(cachePath);
         }
