@@ -12,7 +12,6 @@
 #include <QMutex>
 #include <QDateTime>
 #include <QIODevice>
-#include <QTextCodec>
 
 #include <iostream>
 
@@ -509,7 +508,6 @@ public:
     QList<AbstractAppender*> appenders;
     mutable QMutex loggerMutex;
 
-    QMap<QString, bool> categories;
     QMultiMap<QString, AbstractAppender*> categoryAppenders;
     QString defaultCategory;
 
@@ -623,8 +621,15 @@ Logger::~Logger()
 
     QMutexLocker appendersLocker(&d->loggerMutex);
 
-    QSet<AbstractAppender*> appenderList;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    QSet<AbstractAppender *> appenderList{d->appenders.begin(), d->appenders.end()};
+    for (const auto v : d->categoryAppenders.values()) {
+        appenderList.insert(v);
+    }
+#else
+    QSet<AbstractAppender *> appenderList;
     appenderList += d->appenders.toSet() += d->categoryAppenders.values().toSet();
+#endif
     qDeleteAll(appenderList);
 
     delete d->logDevice;
@@ -816,13 +821,8 @@ void Logger::registerCategoryAppender(const QString &category, AbstractAppender
  */
 void Logger::logToGlobalInstance(const QString &category, bool logToGlobal)
 {
-    Q_D(Logger);
-    if (this == globalInstance()) {
-        QMutexLocker locker(&d->loggerMutex);
-        d->categories.insert(category, logToGlobal);
-    } else {
-        globalInstance()->logToGlobalInstance(category, logToGlobal);
-    }
+    Q_UNUSED(category)
+    Q_UNUSED(logToGlobal)
 }
 
 /*!
@@ -979,24 +979,18 @@ void Logger::write(const QDateTime &time, Logger::LogLevel level, const char *fi
 
     bool wasWritten = false;
     bool isGlobalInstance = this == globalInstance();
-    bool linkedToGlobal = isGlobalInstance && d->categories.value(logCategory, false);
 
     if (!logCategory.isNull()) {
         QList<AbstractAppender*> appenders = d->categoryAppenders.values(logCategory);
-        if (appenders.length() == 0) {
-            if (logCategory != d->defaultCategory && !linkedToGlobal && !fromLocalInstance)
-                std::cerr << "No appenders assotiated with category " << qPrintable(logCategory) << std::endl;
-        } else {
-            for (AbstractAppender* appender : appenders)
-                appender->write(time, level, file, line, func, logCategory, msg);
 
+        for (AbstractAppender* appender : appenders)
+            appender->write(time, level, file, line, func, logCategory, msg);
+        if (!appenders.isEmpty())
             wasWritten = true;
-        }
     }
 
-    // the default category is linked to the main logger appenders
-    // global logger instance also writes all linked categories to the main appenders
-    if (logCategory.isNull() || logCategory == d->defaultCategory || linkedToGlobal) {
+    // if we can't find the corresponding category, log will be appended to all Appenders.
+    if (!wasWritten) {
         if (!d->appenders.isEmpty()) {
             for (AbstractAppender* appender : d->appenders)
                 appender->write(time, level, file, line, func, logCategory, msg);
@@ -1031,7 +1025,7 @@ void CuteMessageLogger::write(const char *msg, ...) const
 {
     va_list va;
     va_start(va, msg);
-    m_l->write(m_level, m_file, m_line, m_function, m_category, QString().vsprintf(msg, va));
+    m_l->write(m_level, m_file, m_line, m_function, m_category, QString::vasprintf(msg, va));
     va_end(va);
 }
 
@@ -1049,7 +1043,7 @@ void LoggerTimingHelper::start(const char *msg, ...)
 {
     va_list va;
     va_start(va, msg);
-    m_block = QString().vsprintf(msg, va);
+    m_block = QString::vasprintf(msg, va);
     va_end(va);
 
     m_time.start();
