@@ -22,7 +22,7 @@
 #include "settings/dsettingsgroup.h"
 #include "settings/dsettingsoption.h"
 #include "dsysinfo.h"
-#include "base/dsingleton.h"
+#include "dlicenseinfo.h"
 
 DCORE_USE_NAMESPACE
 
@@ -138,7 +138,6 @@ TEST_F(ut_DUtil, testDSingleton)
 
     qDeleteAll(threads);
     qDeleteAll(testers);
-    delete DSingleton<int>::instance();
 }
 
 TEST_F(ut_DUtil, testTimeFormatter)
@@ -402,13 +401,6 @@ TEST_F(ut_DUtil, testOsVersion)
     ASSERT_TRUE(entry.save());
     ASSERT_TRUE(DSysInfo::uosType() == DSysInfo::UosTypeUnknown);
 
-    // test OsBuild.E
-    for (int i = 0; i < 4; ++i) {
-        entry.setStringValue(QString("%1").arg(11000.107 + qreal(1 << i)), "OsBuild", "Version");
-        ASSERT_TRUE(entry.save());
-        ASSERT_TRUE(DSysInfo::uosArch() == (1 << i));
-    }
-
     // 社区版测试
     entry.setStringValue("Community", "EditionName", "Version");
     entry.setStringValue("社区版", "EditionName[zh_CN]", "Version");
@@ -468,6 +460,27 @@ TEST_F(ut_DUtil, testOsVersion)
     QFile::remove("/tmp/etc/os-version");
 }
 
+TEST_F(ut_DUtil, testLicense)
+{
+    DLicenseInfo licenseInfo;
+    QString jsonContent = u8R"([
+                                {
+                                    "name": "dtk",
+                                    "version": "5.6.8",
+                                    "copyright": "Copyright 2023 THe Uniontech Company Ltd. All rights reserved.",
+                                    "license": "LGPLv3"
+                                }
+                                ]
+                              )";
+    licenseInfo.setLicenseSearchPath(":/data/");
+
+    ASSERT_TRUE(licenseInfo.loadContent(jsonContent.toLatin1()));
+    EXPECT_EQ(licenseInfo.componentInfos().count(), 1);
+    ASSERT_TRUE(licenseInfo.loadFile(":/data/example-license.json"));
+    EXPECT_EQ(licenseInfo.componentInfos().count(), 1);
+    ASSERT_FALSE(licenseInfo.licenseContent("LGPLv3").isEmpty());
+}
+
 TEST_F(ut_DUtil, testDDesktopEntry)
 {
     DDesktopEntry entry("/tmp/etc/os-version");
